@@ -1,6 +1,7 @@
 from django.db import models
-from django.contrib.auth.models import AbstractUser,Group
+from django.contrib.auth.models import AbstractUser, Group
 from xlibrary.fields import ForeignKeyOptional
+# from accountinginfo.models import Ledger
 from invitations.base_invitation import AbstractBaseInvitation
 from django.utils.translation import ugettext_lazy as _
 from invitations.app_settings import app_settings
@@ -15,7 +16,7 @@ from invitations import signals
 from django.conf import settings
 from django.core.exceptions import PermissionDenied
 # from invitations.utils import get_invitation_model
-AuthorModel=getattr(settings,'INVITATIONS_AUTHOR_MODEL','')
+AuthorModel = getattr(settings, 'INVITATIONS_AUTHOR_MODEL', '')
 try:
     from django.urls import reverse
 except ImportError:
@@ -47,6 +48,8 @@ class xManager(models.Manager):
 
     def all(self):
         return super(xManager, self).get_queryset()
+
+
 class GroupOptions(models.Model):
     PRIVILEGE_CHOICES = (
         ('ALL', 'Can access all permitted data'),
@@ -54,7 +57,7 @@ class GroupOptions(models.Model):
         ('SELF', 'Can access permitted data belonging to the logged in user only'),
     )
     groups = models.OneToOneField(
-        Group, on_delete=models.CASCADE, primary_key=True, related_name='option')
+        Group, on_delete=models.CASCADE, primary_key=True, related_name='FK_%(class)s_option')
     privilege = models.CharField(
         max_length=20, choices=PRIVILEGE_CHOICES, null=False, default='ALL',)
 
@@ -62,17 +65,19 @@ class GroupOptions(models.Model):
         self.groups.delete()
         return super(self.__class__, self).delete(*args, **kwargs)
 
+
 class User(AbstractUser):
     class Meta:
-        verbose_name="User"
+        verbose_name = "User"
         verbose_name_plural = "Users"
 
+
 class GuestInvitation(AbstractBaseInvitation):
     email = models.EmailField(unique=True, verbose_name=_('e-mail address'),
                               max_length=app_settings.EMAIL_MAX_LENGTH)
     created = models.DateTimeField(verbose_name=_('created'),
                                    default=timezone.now)
-    authorentity=ForeignKeyOptional(AuthorModel)
+    authorentity = ForeignKeyOptional(AuthorModel)
 
     @classmethod
     def create(cls, email, inviter=None, authorentity=None,  **kwargs):
@@ -120,7 +125,7 @@ class GuestInvitation(AbstractBaseInvitation):
             inviter=self.inviter)
 
     class Meta:
-        verbose_name="Guest Invitation"
+        verbose_name = "Guest Invitation"
         verbose_name_plural = "Guest Invitations"
 
 
